@@ -11,11 +11,12 @@ use strict;
 BEGIN
 {
     use Exporter;
-    use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS %OPTIONS $options $NO_VALIDATION );
+    use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK
+                 %EXPORT_TAGS %OPTIONS $options $NO_VALIDATION );
 
     @ISA = 'Exporter';
 
-    $VERSION = '0.74';
+    $VERSION = '0.75';
 
     my %tags =
         ( types =>
@@ -233,7 +234,7 @@ An array reference such as C<[1, 2, 3]> or C<\@foo>.
 
 =item * HASHREF
 
-A hash reference such as C<{ a => 1, b => 2 }> or C<\%bar>.
+A hash reference such as C<< { a => 1, b => 2 } >> or C<\%bar>.
 
 =item * CODEREF
 
@@ -277,7 +278,7 @@ This is a special option, and is just a shortcut for C<UNDEF | SCALAR>.
 This option is also special, and is just a shortcut for C<GLOB |
 GLOBREF>.  However, it seems likely that most people interested in
 either globs or glob references are likely to really be interested in
-whether the parameter in questoin could be a valid file or directory
+whether the parameter in question could be a valid file or directory
 handle.
 
 =back
@@ -364,15 +365,15 @@ reference, such as:
 
  validate( @_,
            { foo =>
-             callbacks =>
-             { 'smaller than a breadbox' => sub { shift() < $breadbox },
-               'green or blue' =>
-                sub { $_[0] eq 'green' || $_[0] eq 'blue' } } } );
+             { callbacks =>
+               { 'smaller than a breadbox' => sub { shift() < $breadbox },
+                 'green or blue' =>
+                  sub { $_[0] eq 'green' || $_[0] eq 'blue' } } } );
 
  validate( @_,
            { foo =>
-             callbacks =>
-             { 'bigger than baz' => sub { $_[0] > $_[1]->{baz} } } } );
+             { callbacks =>
+               { 'bigger than baz' => sub { $_[0] > $_[1]->{baz} } } } } );
 
 =head2 Untainting
 
